==> forms-v5.2.1.tar.gz: forms/l10n/be.js <==
OC.L10N.register(
    "forms",
    {
    "No" : "Не",
    "Yes" : "Так",
    "Question" : "Пытанне",
    "Copy" : "Капіяваць",
    "Shared by %s" : "Абагуліў(-ла) %s",
    "User display name" : "Імя карыстальніка для паказу",
    "Shared with you" : "Абагулена з вамі",
    "Select groups" : "Выберыце групы",
    "Results" : "Вынікі",
    "Cancel" : "Скасаваць",
    "Options" : "Варыянты",
    "Delete answer" : "Выдаліць адказ",
    "Required" : "Абавязкова",
    "Copy question" : "Капіяваць пытанне",
    "Delete question" : "Выдаліць пытанне",
    "Delete" : "Выдаліць",
    "Uploading …" : "Запампоўванне …",
    "Other" : "Іншае",
    "never" : "ніколі",
    "Group" : "Група",
    "Team" : "Каманда",
    "Permissions" : "Дазволы",
    "Share link" : "Абагуліць спасылку",
    "Copy to clipboard" : "Капіяваць у буфер абмену",
    "Remove link" : "Выдаліць спасылку",
    "An error occurred while transfering ownership" : "Падчас перадачы права ўласнасці адбылася памылка",
    "Transfer ownership" : "Перадаць права ўласнасці",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "Вы збіраецеся перадаць права ўласнасці на {name} іншаму ўліковаму запісу. Выберыце ўліковы запіс, якому вы хочаце перадаць права ўласнасці.",
    "View" : "Выгляд",
    "Edit" : "Рэдагаваць",
    "Share" : "Абагуліць",
    "Description" : "Апісанне",
    "Download" : "Спампаваць",
    "Search" : "Пошук",
    "No results found" : "Вынікаў не знойдзена",
    "Sharing" : "Абагульванне",
    "Settings" : "Налады",
    "Submit" : "Адправіць",
    "Clear" : "Ачысціць",
    "Clear form" : "Ачысціць форму",
    "Cannot copy, please copy the link manually" : "Немагчыма скапіяваць, скапіюйце спасылку ўручную",
    "No recommendations. Start typing." : "Няма рэкамендацый. Пачніце друкаваць.",
    "File" : "Файл",
    "Date" : "Дата",
    "Time" : "Час",
    "Document" : "Дакумент",
    "Text" : "Тэкст",
    "Phone number" : "Нумар тэлефона",
    "Email address" : "Адрас электроннай пошты"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> forms-v5.2.2.tar.gz: forms/l10n/be.js <==
OC.L10N.register(
    "forms",
    {
    "No" : "Не",
    "Yes" : "Так",
    "Question" : "Пытанне",
    "Copy" : "Капіяваць",
    "Shared by %s" : "Абагуліў(-ла) %s",
    "User display name" : "Імя карыстальніка для паказу",
    "Shared with you" : "Абагулена з вамі",
    "Loading forms …" : "Загрузка форм …",
    "Select groups" : "Выберыце групы",
    "Results" : "Вынікі",
    "Cancel" : "Скасаваць",
    "Options" : "Варыянты",
    "Delete answer" : "Выдаліць адказ",
    "Required" : "Абавязкова",
    "Copy question" : "Капіяваць пытанне",
    "Delete question" : "Выдаліць пытанне",
    "Delete" : "Выдаліць",
    "Uploading …" : "Запампоўванне …",
    "Other" : "Іншае",
    "never" : "ніколі",
    "Search for user, group or team …" : "Пошук карыстальніка, групы або каманды …",
    "Group" : "Група",
    "Team" : "Каманда",
    "Permissions" : "Дазволы",
    "Share link" : "Абагуліць спасылку",
    "Copy to clipboard" : "Капіяваць у буфер абмену",
    "Remove link" : "Выдаліць спасылку",
    "Internal link" : "Унутраная спасылка",
    "An error occurred while transfering ownership" : "Падчас перадачы права ўласнасці адбылася памылка",
    "Transfer ownership" : "Перадаць права ўласнасці",
    "You're going to transfer the ownership of {name} to another account. Please select the account to which you want to transfer ownership." : "Вы збіраецеся перадаць права ўласнасці на {name} іншаму ўліковаму запісу. Выберыце ўліковы запіс, якому вы хочаце перадаць права ўласнасці.",
    "View" : "Выгляд",
    "Edit" : "Рэдагаваць",
    "Share" : "Абагуліць",
    "Loading {title} …" : "Загрузка {title} …",
    "Description" : "Апісанне",
    "Download" : "Спампаваць",
    "Search" : "Пошук",
    "Loading responses …" : "Загрузка адказаў …",
    "No results found" : "Вынікаў не знойдзена",
    "Sharing" : "Абагульванне",
    "Settings" : "Налады",
    "Submit" : "Адправіць",
    "Clear" : "Ачысціць",
    "Submitting form …" : "Адпраўка формы …",
    "Clear form" : "Ачысціць форму",
    "Cannot copy, please copy the link manually" : "Немагчыма скапіяваць, скапіюйце спасылку ўручную",
    "No recommendations. Start typing." : "Няма рэкамендацый. Пачніце друкаваць.",
    "No elements found." : "Элементаў не знойдзена.",
    "File" : "Файл",
    "Date" : "Дата",
    "Time" : "Час",
    "Document" : "Дакумент",
    "Text" : "Тэкст",
    "Phone number" : "Нумар тэлефона",
    "Email address" : "Адрас электроннай пошты",
    "Uploading …" : "Запампоўванне …"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
